Learn R Programming

wrassp (version 0.1.2)

acfana: acfana

Description

acfana function adapted from libassp

Usage

acfana(listOfFiles = NULL, optLogFilePath = NULL, beginTime = 0,
  centerTime = FALSE, endTime = 0, windowShift = 5, windowSize = 20,
  effectiveLength = TRUE, window = "BLACKMAN", analysisOrder = 0,
  energyNormalization = FALSE, lengthNormalization = FALSE, toFile = TRUE,
  explicitExt = NULL, outputDirectory = NULL,
  forceToLog = useWrasspLogger)

Arguments

listOfFiles
vector of file paths to be processed by function
optLogFilePath
path to option log file
beginTime
=
centerTime
=
endTime
=
windowShift
= : set analysis window shift to ms (default: 5.0)
windowSize
= : set analysis window size to ms; overrules EffectiveLength parameter
effectiveLength
make window size effective rather than exact
window
= : set analysis window function to (default: BLACKMAN)
analysisOrder
= : set analysis order to (default: 0 = sample rate in kHz + 3)
energyNormalization
calculate energy-normalized autocorrelation
lengthNormalization
calculate length-normalized autocorrelation
toFile
write results to file (default extension is .acf)
explicitExt
set if you wish to overwride the default extension
outputDirectory
directory in which output files are stored. Defaults to NULL, i.e. the directory of the input files
forceToLog
is set by the global package variable useWrasspLogger. This is set to FALSE by default and should be set to TRUE is logging is desired.

Value

  • nrOfProcessedFiles or if only one file to process return AsspDataObj of that file

Details

Analysis of short-term autocorrelation function of the signals in . Analysis results will be written to a file with the base name of the input file and extension '.acf'. Default output is in SSFF binary format (track 'acf').

Examples

Run this code
# get path to audio file
path2wav <- list.files(system.file("extdata", package = "wrassp"),
                       pattern = glob2rx("*.wav"),
                       full.names = TRUE)[1]

# calculate short-term autocorrelation
res <- acfana(path2wav, toFile=FALSE)

# plot short-term autocorrelation values
matplot(seq(0,numRecs.AsspDataObj(res) - 1) / rate.AsspDataObj(res) +
        attr(res, 'startTime'),
        res$acf,
        type='l',
        xlab='time (s)',
        ylab='short-term autocorrelation values')

Run the code above in your browser using DataLab