Learn R Programming

wrassp (version 0.1.2)

rfcana: rfcana

Description

rfcana function adapted from libassp

Usage

rfcana(listOfFiles = NULL, optLogFilePath = NULL, beginTime = 0,
  centerTime = FALSE, endTime = 0, windowShift = 5, windowSize = 20,
  effectiveLength = TRUE, window = "BLACKMAN", order = 0,
  preemphasis = -0.95, lpType = "RFC", toFile = TRUE,
  explicitExt = NULL, outputDirectory = NULL,
  forceToLog = useWrasspLogger)

Arguments

listOfFiles
vector of file paths to be processed by function
optLogFilePath
path to option log file
beginTime
=
centerTime
set single-frame analysis with the analysis window centred at
endTime
=
windowShift
= : set analysis window shift to ms (default: 5.0)
windowSize
= : set analysis window size to ms; overrules effectiveLength option
effectiveLength
make window size effective rather than exact
window
= : set analysis window function to (default: BLACKMAN)
order
= : set prediction order to (default: sample rate in kHz + 3)
preemphasis
= : set pre-emphasis factor to (default: -0.95)
lpType
= : calculate LP parameters; may be: "ARF": area function "LAR": log area ratios "LPC": linear prediction filter coefficients "RFC": reflection coefficients (default)
toFile
write results to file (default extension dependent on LpType .arf/.lar/.lpc/.rfc)
explicitExt
set if you wish to overwride the default extension
outputDirectory
directory in which output files are stored. Defaults to NULL, i.e. the directory of the input files
forceToLog
is set by the global package variable useWrasspLogger. This is set to FALSE by default and should be set to TRUE is logging is desired.

Value

  • nrOfProcessedFiles or if only one file to process return AsspDataObj of that file

Details

Linear Prediction analysis of using the autocorrelation method and the Durbin recursion. This program calculates the RMS amplitudes of the input and residual signal in dB and, per default, reflection coefficients (see '-t' option). Analysis results will be written to a file with the base name of the input file and the parameter type in lower case as extension (e.g. '.rfc'). Default output is in SSFF binary format (tracks 'rms', 'gain' and the LP type in lower case).

Examples

Run this code
# get path to audio file
path2wav <- list.files(system.file("extdata", package = "wrassp"),
                       pattern = glob2rx("*.wav"),
                       full.names = TRUE)[1]

# perform linear prediction analysis
res <- rfcana(path2wav, toFile=FALSE)

# plot reflection coefficients
matplot(seq(0,numRecs.AsspDataObj(res) - 1) / rate.AsspDataObj(res) +
          attr(res, 'startTime'),
        res$rfc,
        type='l',
        xlab='time (s)',
        ylab='reflection coefficient values')

Run the code above in your browser using DataLab