Learn R Programming

wrassp (version 0.1.2)

rmsana: rmsana

Description

rmsana function adapted from libassp

Usage

rmsana(listOfFiles = NULL, optLogFilePath = NULL, beginTime = 0,
  centerTime = FALSE, endTime = 0, windowShift = 5, windowSize = 20,
  effectiveLength = TRUE, linear = FALSE, window = "HAMMING",
  toFile = TRUE, explicitExt = NULL, outputDirectory = NULL,
  forceToLog = useWrasspLogger)

Arguments

listOfFiles
vector of file paths to be processed by function
optLogFilePath
path to option log file
beginTime
=
centerTime
=
endTime
=
windowShift
= : set analysis window shift to ms (default: 5.0)
windowSize
= : set analysis window size to ms; overrules effectiveLength option
effectiveLength
make window size effective rather than exact
linear
calculate linear RMS values (default: values in dB)
window
= : set analysis window function to (default: HAMMING)
toFile
write results to file (default extension is .rms)
explicitExt
set if you wish to overwride the default extension
outputDirectory
directory in which output files are stored. Defaults to NULL, i.e. the directory of the input files
forceToLog
is set by the global package variable useWrasspLogger. This is set to FALSE by default and should be set to TRUE is logging is desired.

Value

  • nrOfProcessedFiles or if only one file to process return AsspDataObj of that file

Details

Analysis of short-term Root Mean Square amplitude of the signal in . Per default, the RMS values are expressed in decibel (dB) so that they correspond to the short-term power of the signal. Analysis results will be written to a file with the base name of the input file and extension '.rms'. Default output is in SSFF binary format (track 'rms').

Examples

Run this code
# get path to audio file
path2wav <- list.files(system.file("extdata", package = "wrassp"),
                       pattern = glob2rx("*.wav"),
                       full.names = TRUE)[1]

# calculate rms values
res <- rmsana(path2wav, toFile=FALSE)

# plot rms values
plot(seq(0,numRecs.AsspDataObj(res) - 1) / rate.AsspDataObj(res) +
       attr(res, 'startTime'),
     res$rms,
     type='l',
     xlab='time (s)',
     ylab='RMS energy (dB)')

Run the code above in your browser using DataLab