= : set single-frame analysis with the analysis window centred at seconds;
overrules BeginTime, EndTime and WindowShift options
endTime
= : set end of analysis interval to seconds (default: 0 = end of file)
windowShift
= : set analysis window shift to ms (default: 5.0)
windowSize
= : set analysis window size to ms; overrules EffectiveLength parameter
effectiveLength
make window size effective rather than exact
window
= : set analysis window function to (default: BLACKMAN)
analysisOrder
= : set analysis order to (default: 0 = sample rate in kHz + 3)
energyNormalization
calculate energy-normalized autocorrelation
lengthNormalization
calculate length-normalized autocorrelation
toFile
write results to file (default extension is .acf)
explicitExt
set if you wish to overwride the default extension
outputDirectory
directory in which output files are stored. Defaults to NULL, i.e.
the directory of the input files
forceToLog
is set by the global package variable useWrasspLogger. This is set
to FALSE by default and should be set to TRUE is logging is desired.
Value
nrOfProcessedFiles or if only one file to process return AsspDataObj of that file
Details
Analysis of short-term autocorrelation function of
the signals in .
Analysis results will be written to a file with the
base name of the input file and extension '.acf'.
Default output is in SSFF binary format (track 'acf').