= : maximum zero crossing rate in Hz (default: 3000)
minProb
= : minimum quality value of F0 fit (default: 0.520)
plainSpectrum
use plain rather than masked power spectrum
toFile
write results to file (default extension is .pit)
explicitExt
set if you wish to overwride the default extension
outputDirectory
directory in which output files are stored. Defaults to NULL, i.e.
the directory of the input files
forceToLog
is set by the global package variable useWrasspLogger. This is set
to FALSE by default and should be set to TRUE is logging is desired.
Value
nrOfProcessedFiles or if only one file to process return AsspDataObj of that file
Details
Pitch analysis of the speech signal in using
Michel's/Modified Harmonic Sieve algorithm.
Analysis results will be written to a file with the
base name of the input file and extension '.pit'.
Default output is in SSFF binary format (track 'pitch').