wrassp.logger: wrassp.logger
Description
Designated logger for the wrassp signal processing functionsUsage
wrassp.logger(fName, fOpts, optLogFilePath, listOfFiles)
Arguments
fName
the name of the function calling the logger
fOpts
are the function options given by the user aquired by match.call
optLogFilePath
path to option log file
listOfFiles
vector of file paths that the spf calling the logger processed
Details
Function logs the call to a signal processing function (spf) of wrassp.
It is called by default if the forceToLog option of the spf is not set to
false. I tries to format the output in an easily readable fashion.